@@ -10,6 +10,7 @@ from collections import namedtuple
 import pandas as pd
 import requests
 from retrying import retry
+from polly.help import example, doc
 
 from polly import constants as const
 
@@ -36,30 +37,275 @@ QUERY_API_V2 = "v2"
 
 
 class OmixAtlas:
+    """
+    OmixAtlas class enables users to create, update an Omixatlas, get summary of an Omixatlas, get schema of \
+data at dataset, sample and feature level, query metadata, download data, save file to workspace and data \
+converter functions.
+
+
+    ``Args:``
+        |  ``token (str):`` token copy from polly.
+
+    We can initialize a OmixAtlas class object using.
+
+
+    .. code::
+
+
+            from polly.omixatlas import OmixAtlas
+            omixatlas = OmixAtlas(token)
+
+    If you are authorised then you can initialize object without token to know about :ref:`authentication <auth>`.
+    """
+
+    example = classmethod(example)
+    doc = classmethod(doc)
+
     def __init__(self, token=None, env="polly") -> None:
         self.session = Polly.get_session(token, env=env)
         self.base_url = f"https://v2.api.{self.session.env}.elucidata.io"
         self.discover_url = f"https://api.discover.{self.session.env}.elucidata.io"
         self.elastic_url = (
-            f"https://api.datalake.discover.{self.session.env}.elucidata.io/elastic"
+            f"https://api.datalake.discover.{self.session.env}.elucidata.io/elastic/v2"
         )
         self.resource_url = f"{self.base_url}/v1/omixatlases"
 
-    def get_all_omixatlas(self):
+    def get_all_omixatlas(
+        self, query_api_version="v2", count_by_source=True, count_by_data_type=True
+    ):
+        """
+        .. _targetget:
+
+        This function will return the summary of all the Omixatlas on Polly which the user has access to.
+
+        ``Args:``
+            |  None
+
+        ``Returns:``
+            It will return a list of objects like this.
+
+            .. code::
+
+
+                    {
+                    'repo_name': 'repo',
+                    'repo_id': '1646',
+                    'indexes': {
+                    'gct_metadata': 'repo_gct_metadata',
+                        'h5ad_metadata': 'repo_h5ad_metadata',
+                        'csv': 'repo_csv',
+                        'files': 'repo_files',
+                        'json': 'repo_json',
+                        'ipynb': 'repo_ipynb',
+                        'gct_data': 'repo_gct_data',
+                        'h5ad_data': 'repo_h5ad_data'
+                        },
+                    'diseases': [],
+                    'organisms': [],
+                    'sources': [],
+                    'datatypes': [],
+                    'dataset_count': 0,
+                    'disease_count': 0,
+                    'tissue_count': 0,
+                    'organism_count': 0,
+                    'cell_line_count': 0,
+                    'cell_type_count': 0,
+                    'drug_count': 0,
+                    'data_type_count': 0,
+                    'data_source_count': 0,
+                    'sample_count': 0,
+                    'normal_sample_count': 0
+                    }
+
+        | To use this function import Omixatlas class and make a object.
+
+
+        .. code::
+
+
+                from polly.omixatlas import OmixAtlas
+                omixatlas = OmixAtlas(token)
+                # to use OmixAtlas class functions
+                omixatlas.get_all_omixatlas()
+
+        """
+
         url = self.resource_url
-        params = {"summarize": "true"}
+        if query_api_version == "v2":
+            if count_by_source and count_by_data_type:
+                params = {
+                    "summarize": "true",
+                    "v2": "true",
+                    "count_by_source": "true",
+                    "count_by_data_type": "true",
+                }
+            elif count_by_source:
+                params = {"summarize": "true", "v2": "true", "count_by_source": "true"}
+            elif count_by_data_type:
+                params = {
+                    "summarize": "true",
+                    "v2": "true",
+                    "count_by_data_type": "true",
+                }
+            else:
+                params = {
+                    "summarize": "true",
+                    "v2": "true",
+                }
+        elif query_api_version == "v1":
+            params = {"summarize": "true"}
+        else:
+            raise wrongParamException("Incorrect query param version passed")
         response = self.session.get(url, params=params)
         error_handler(response)
         return response.json()
 
-    def omixatlas_summary(self, key: str):
+    def omixatlas_summary(
+        self,
+        key: str,
+        query_api_version="v2",
+        count_by_source=True,
+        count_by_data_type=True,
+    ):
+        """
+        This function will return you a object that contain information about a given Omixatlas.
+
+        ``Args:``
+            |  ``key (str) :`` repo_id or repo_name.
+
+        ``Returns:``
+            It will return a object like this.
+
+            .. code::
+
+
+                    {
+                    'repo_name': 'repo',
+                    'repo_id': '1646',
+                    'indexes': {
+                        'gct_metadata': 'repo_gct_metadata',
+                        'h5ad_metadata': 'repo_h5ad_metadata',
+                        'csv': 'repo_csv',
+                        'files': 'repo_files',
+                        'json': 'repo_json',
+                        'ipynb': 'repo_ipynb',
+                        'gct_data': 'repo_gct_data',
+                        'h5ad_data': 'repo_h5ad_data'
+                        },
+                    'diseases': [],
+                    'organisms': [],
+                    'sources': [],
+                    'datatypes': [],
+                    'dataset_count': 0,
+                    'disease_count': 0,
+                    'tissue_count': 0,
+                    'organism_count': 0,
+                    'cell_line_count': 0,
+                    'cell_type_count': 0,
+                    'drug_count': 0,
+                    'data_type_count': 0,
+                    'data_source_count': 0,
+                    'sample_count': 0,
+                    'normal_sample_count': 0
+                    }
+
+        |  To use this function see the code below.
+
+        .. code::
+
+
+                from polly.omixatlas import OmixAtlas
+                omixatlas = OmixAtlas(token)
+                # to use OmixAtlas class functions
+                omixatlas.omixatlas_summary(key)
+        """
+
         url = f"{self.resource_url}/{key}"
-        params = {"summarize": "true"}
-        response = self.session.get(url, params=params)
+        if query_api_version == "v2":
+            if count_by_source and count_by_data_type:
+                params = {
+                    "summarize": "true",
+                    "v2": "true",
+                    "count_by_source": "true",
+                    "count_by_data_type": "true",
+                }
+            elif count_by_source:
+                params = {"summarize": "true", "v2": "true", "count_by_source": "true"}
+            elif count_by_data_type:
+                params = {
+                    "summarize": "true",
+                    "v2": "true",
+                    "count_by_data_type": "true",
+                }
+            else:
+                params = {
+                    "summarize": "true",
+                    "v2": "true",
+                }
+        elif query_api_version == "v1":
+            params = {"summarize": "true"}
+        else:
+            raise wrongParamException("Incorrect query param version passed")
+        if params:
+            response = self.session.get(url, params=params)
         error_handler(response)
         return response.json()
 
     def get_omixatlas(self, key: str):
+        """
+        This function will return a omixatlas repository in polly.
+
+        ``Args:``
+            |  ``key:`` repo name or repo id.
+
+        ``Returns:``
+            It will return a objects like this.
+
+            .. code::
+
+
+                    {
+                    'repo_name': 'repo',
+                    'repo_id': '1646',
+                    'indexes': {
+                    'gct_metadata': 'repo_gct_metadata',
+                        'h5ad_metadata': 'repo_h5ad_metadata',
+                        'csv': 'repo_csv',
+                        'files': 'repo_files',
+                        'json': 'repo_json',
+                        'ipynb': 'repo_ipynb',
+                        'gct_data': 'repo_gct_data',
+                        'h5ad_data': 'repo_h5ad_data'
+                        },
+                    'diseases': [],
+                    'organisms': [],
+                    'sources': [],
+                    'datatypes': [],
+                    'dataset_count': 0,
+                    'disease_count': 0,
+                    'tissue_count': 0,
+                    'organism_count': 0,
+                    'cell_line_count': 0,
+                    'cell_type_count': 0,
+                    'drug_count': 0,
+                    'data_type_count': 0,
+                    'data_source_count': 0,
+                    'sample_count': 0,
+                    'normal_sample_count': 0
+                    }
+
+        | To use this function import Omixatlas class and make a object.
+
+
+        .. code::
+
+
+                from polly.omixatlas import OmixAtlas
+                omixatlas = OmixAtlas(token)
+                # to use OmixAtlas class functions
+                omixatlas.get_omixatlas('9')
+
+        """
         url = f"{self.resource_url}/{key}"
         response = self.session.get(url)
         error_handler(response)
@@ -69,9 +315,40 @@ class OmixAtlas:
         self,
         query: str,
         experimental_features=None,
-        query_api_version=QUERY_API_V1,
+        query_api_version=QUERY_API_V2,
         page_size=None,  # Note: do not increase page size more than 999
     ):
+        """
+        This function will return a dataframe containing the datasets or sample as per the SQL query.
+
+        ``Args:``
+            |  ``query (str) :`` sql query  on  omixatlas for example - "SELECT * FROM geo.datasets".
+            |  ``experimental_features :`` :ref:`this section includes in querying metadata <target>`.
+            |  ``query_api_version (str) :`` v1 or v2.
+            |  ``page_size (int):`` page size for query.
+
+
+
+        ``Returns:``
+            |  It will return a dataframe that contains metadata information as defined in the schema.
+
+        ``Errors:``
+            |  ``UnfinishedQueryException:`` when query has not finised the execution.
+            |  ``QueryFailedException:`` when query failed to execute.
+
+
+        .. code::
+
+
+                from polly.omixatlas import OmixAtlas
+                omixatlas = OmixAtlas(token)
+                # to use OmixAtlas class functions
+                query = "SELECT * FROM geo.datasets"
+                results = omixatlas.query_metadata(query, query_api_version="v2")
+                print(results)
+
+        |  To know about quering metadata :ref:`Querying metadata <targetq>`.
+        """
         max_page_size = 999
         if page_size is not None and page_size > max_page_size:
             raise ValueError(
@@ -234,23 +511,31 @@ class OmixAtlas:
         """
         Gets the schema of a repo id for the given repo_key and
         schema_type definition at the top level
-        params:
-        repo_key => str
-        schema_type_dict => dictionary {schema_level:schema_type}
-        example {'dataset': 'files', 'sample': 'gct_metadata'}
-        Ouput:
-            {
-                "data": {
-                    "id": "<REPO_ID>",
-                    "type": "schema",
-                    "attributes": {
-                        "schema_type": "files | gct_metadata | h5ad_metadata",
-                        "schema": {
-                            ... field definitions
+
+        ``Args:``
+            |  ``repo_key (str) :`` repo id or repo name
+            |  ``schema_type_dict (dictionary) :`` {schema_level:schema_type}
+            |  example {'dataset': 'files', 'sample': 'gct_metadata'}
+
+        ``Returns:``
+
+            .. code::
+
+
+                    {
+                        "data": {
+                            "id": "<REPO_ID>",
+                            "type": "schema",
+                            "attributes": {
+                                "schema_type": "files | gct_metadata | h5ad_metadata",
+                                "schema": {
+                                    ... field definitions
+                                }
+                            }
                         }
                     }
-                }
-            }
+
+        :meta private:
         """
         resp_dict = {}
         schema_base_url = f"{self.discover_url}/repositories"
@@ -310,46 +595,93 @@ class OmixAtlas:
         self, repo_key: str, schema_level=["dataset", "sample"], source="", data_type=""
     ) -> dict:
         """
-        Input params:
-                repo_key => str => <owner_name.repo_name>/<repo_id>
-                schema_level => list => Default value => ['dataset', 'sample']
-            Output:
-                {
-                    'dataset':pd.DataFrame,
-                    'sample':pd.DataFrame
-                }
-            DataFrame consists of schema metadata summary
-            i) schema_type : gct_metadata or h5ad_metadata i.e Column Fields (Sample)
-            metdata schema definition for sample:
-                schema:{
-                    "<SOURCE>": {
-                        "<DATATYPE>": {
-                            "<FIELD_NAME>": {
-                            "type": "text | integer | object",
-                            "description": "string", (Min=1, Max=100)
-                            },
-                            ... other fields
-                        }
-                        ... other Data types
+        Using this function to extract the schema of an OmixAtlas.
+
+        ``Args:``
+            |  ``repo_key (str) :`` repo_id OR repo_name. This is a mandatory field.
+            |  ``schema_level (list) :`` The default value is ['dataset', 'sample']. The users can use ['dataset'] \
+OR ['sample'] to fetch the schema of dataset OR sample level metadata respectively.
+            |  ``source (str) :`` is the source from where data is ingested into the Omixatlas.
+            |  ``data_type (str) :`` is the datatype for which user wants to get the schema for. The default \
+value is 'all', which will fetch the schema of all datatypes except single cell. To fetch the schema for \
+single cell datatype from an OmixAtlas, the user should use 'single_cell'.
+
+        ``Returns:``
+            |  It will contain the schema for dataset, sample as dataframe.
+
+            .. code::
+
+
+
+                    {
+                        'dataset':pd.DataFrame,
+                        'sample':pd.DataFrame
                     }
-                    ... other Sources
-                }
-            ii) schema_type : files i.e Global Fields (dataset)
-            PS :- ALL, ALL keys is not rigid for dataset level schema also
-            There it can be <SOURCE> and <DATATYPE> key also
-            metadata schema definition for a dataset:
-                schema:{
-                        "ALL": {
-                            "ALL": {
-                                "<FIELD_NAME>": {
-                                "type": "text | integer | object",
-                                "description": "string", (Min=1, Max=100)
-                                },
-                                ... other fields
-                            }
-                        }
-            iii) schema_type : gct_metadata i.e Row Fields (Feature)
-            Not there right now
+            |  you can access dataset, sample schema in following manner.
+
+            .. code::
+
+
+                    # import pandas as pd
+                    # pd.set_option('expand_frame_repr', False)
+                    # use above two line if your dataframe does not print in single line
+                    schema = omixatlas.get_schema("9", ['dataset', 'sample'])
+
+                    # to fetch the dataframe with dataset level metadata
+                    print(schema.dataset)
+
+                    # to fetch the dataframe with sample level metadata
+                    print(schema.sample)
+
+            | ``schema.dataset`` will contain dataframe you can print them in a table form like this.
+
+            .. csv-table::
+                :header: "", Source, Datatype, "Field Name", "Field Description", "Field Type"
+                :delim: |
+
+                0  |  all |  all |   curated_organism |       Orgnism from which the samples were derived  |     text
+                1  |  all |  all |            src_uri |   Unique URI derived from data file's S3 location  |     text
+                2  |  all |  all |  total_num_samples |              Total number of samples in a dataset  |  integer
+                3  |  all |  all |               year |           Year in which the dataset was published  |  integer
+                4  |  all |  all |        description |                        Description of the dataset  |     text
+                5  |  all |  all |  curated_cell_line | Cell lines from which the samples were derived...  |     text
+                6  |  all | all  |   data_table_name  | Name of the data table associated with data file   |    text
+                7  |  all |  all | data_table_version | Current version of the data table associated w...  |  integer
+
+            | ``schema.sample`` will contain dataframe you can print them in a table form like this.
+
+            .. csv-table::
+                :header: "", "Source", "Datatype", "Field Name", "Field Description", "Field Type"
+                :delim: |
+
+                0  |  all  |  all  |   growth_protocol_ch1 |                                                NA |    text
+                1  |  all  |  all  |               src_uri | Unique URI derived from source data file's S3 ... |    text
+                2  |  all  |  all  |             sample_id |            Unique ID associated with every sample |    text
+                3  |  all  |  all  | curated_gene_modified |        Gene modified through genetic modification |    text
+                4  |  all  |  all  |              dose_ch1 |                                                NA |    text
+                5  |  all  |  all  |   curated_cohort_name |    Name of the cohort to which the sample belongs |    text
+                6  |  all  |  all  |       curated_control | Signifies whether the given sample is a contro... | integer
+                7  |  all  |  all  |        src_dataset_id | Dataset ID of the file this data entity origin... |    text
+
+        ``Errors:``
+            |  ``invalidApiResponseException:`` datakey, attributes, schema_type is missing in repository schema.
+            |  ``RequestException:`` Schema not found.
+            |  ``paramException:`` repo_key and schema_type_dict are either empty or its datatype is not correct.
+
+
+        |  Example to fetch dataset and sample level schema for all datatypes from all sources in GEO Omixatlas.
+
+
+        .. code::
+
+
+                schema = omixatlas.get_schema("geo", ['dataset', 'sample'], "all", "all")
+
+                # to fetch the dataframe with dataset level metadata
+                print(schema.dataset)
+
+                # to fetch the dataframe with sample level metadata
+                print(schema.sample)
         """
 
         # get schema_type_dict
@@ -373,6 +705,8 @@ class OmixAtlas:
     def return_schema_data(self, df_map: dict) -> tuple:
         """
         Return schema data as named tuple
+
+        :meta private:
         """
         # change key value from index -> schema_level
         # index and schema_level is in the const indexes_schema_level_map
@@ -388,48 +722,53 @@ class OmixAtlas:
         self, repo_key: str, schema_level=["dataset", "sample"], source="", data_type=""
     ) -> dict:
         """
-        Input params:
-                repo_key => str => <owner_name.repo_name>/<repo_id>
-                schema_level => list => Default value => ['dataset', 'sample']
-            Output:
-                {
-                    'dataset':pd.DataFrame,
-                    'sample':pd.DataFrame
-                }
-            DataFrame consists of schema metadata summary
-            i) schema_type : gct_metadata or h5ad_metadata i.e Column Fields (Sample)
-            metdata schema definition for sample:
-                schema:{
-                    "<SOURCE>": {
-                        "<DATATYPE>": {
-                            "<FIELD_NAME>": {
-                            "type": "text | integer | object",
-                            "description": "string", (Min=1, Max=100)
-                            },
-                            ... other fields
-                        }
-                        ... other Data types
-                    }
-                    ... other Sources
-                }
-            ii) schema_type : files i.e Global Fields (dataset)
-            PS :- ALL, ALL keys is not rigid for dataset level schema also
-            There it can be <SOURCE> and <DATATYPE> key also
-            metadata schema definition for a dataset:
-                schema:{
-                        "ALL": {
-                            "ALL": {
-                                "<FIELD_NAME>": {
-                                "type": "text | integer | object",
-                                "description": "string", (Min=1, Max=100)
-                                },
-                                ... other fields
-                            }
-                        }
-            iii) schema_type : gct_metadata i.e Row Fields (Feature)
-            Not there right now
-        """
 
+        :meta private:
+
+        To visulize schema of a repository.
+
+        ``Args:``
+            |  ``repo_key => str =>`` <owner_name.repo_name>/<repo_id>
+            |  ``schema_level => list`` => Default value => ['dataset', 'sample']
+
+        ``Returns:``
+            |  {
+            |      'dataset':pd.DataFrame,
+            |      'sample':pd.DataFrame
+            |  }
+            |  DataFrame consists of schema metadata summary
+            |  i) schema_type : gct_metadata or h5ad_metadata i.e Column Fields (Sample)
+            |  metdata schema definition for sample:
+            |      schema:{
+            |          "<SOURCE>": {
+            |              "<DATATYPE>": {
+            |                  "<FIELD_NAME>": {
+            |                  "type": "text | integer | object",
+            |                  "description": "string", (Min=1, Max=100)
+            |                  },
+            |                  ... other fields
+            |              }
+            |              ... other Data types
+            |          }
+            |          ... other Sources
+            |      }
+            |  ii) schema_type : files i.e Global Fields (dataset)
+            |  PS :- ALL, ALL keys is not rigid for dataset level schema also
+            |  There it can be <SOURCE> and <DATATYPE> key also
+            |  metadata schema definition for a dataset:
+            |      schema:{
+            |              "ALL": {
+            |                  "ALL": {
+            |                      "<FIELD_NAME>": {
+            |                      "type": "text | integer | object",
+            |                      "description": "string", (Min=1, Max=100)
+            |                      },
+            |                      ... other fields
+            |                  }
+            |              }
+            |  iii) schema_type : gct_metadata i.e Row Fields (Feature)
+            |  Not there right now
+        """
         # get schema_type_dict
         schema_type_dict = self.get_schema_type(schema_level, data_type)
 
@@ -454,14 +793,14 @@ class OmixAtlas:
     def get_schema_type(self, schema_level: list, data_type: str) -> dict:
         """
         Compute schema_type based on data_type and schema_level
-        schema_level         schema_type
-        ------------------------------------
-        dataset         ==   file
-        ----------------------------------
-        sample          ==   gct_metadata
-        -----------------------------------
-        sample and      ==    h5ad_metadata
-        single cell
+
+        |  schema_level   --------    schema_type
+        |  dataset       --------     file
+        |  sample    --------      gct_metadata
+        |  sample and  ------       h5ad_metadata
+        |  single cell
+
+        :meta private:
         """
         if schema_level and isinstance(schema_level, list):
             if "dataset" in schema_level and "sample" in schema_level:
@@ -502,32 +841,33 @@ class OmixAtlas:
     def flatten_nested_schema_dict(self, nested_schema_dict: dict) -> dict:
         """
         Flatten the nested dict
-         Input:
-         schema:{
-                   "<SOURCE>": {
-                       "<DATATYPE>": {
-                           "<FIELD_NAME>": {
-                           "type": "text | integer | object",
-                           "description": "string", (Min=1, Max=100)
-                           },
-                           ... other fields
-                       }
-                       ... other Data types
-                   }
-                   ... other Sources
-               }
 
-         Output:
-                  {
-                      'Source':source_list,
-                      'Datatype': datatype_list,
-                      'Field Name':field_name_list,
-                      'Field Description':field_desc_list,
-                      'Field Type': field_type_list,
-                      'Is Curated': curated_bool_val,
-                      'Is Array': is_array_bool_value,
-                  }
+        ``Args:``
+            |  schema:{
+            |         "<SOURCE>": {
+            |             "<DATATYPE>": {
+            |                 "<FIELD_NAME>": {
+            |                 "type": "text | integer | object",
+            |                 "description": "string", (Min=1, Max=100)
+            |                 },
+            |                 ... other fields
+            |             }
+            |             ... other Data types
+            |         }
+            |         ... other Sources
+            |     }
 
+        ``Returns:``
+            |  {
+            |      'Source':source_list,
+            |      'Datatype': datatype_list,
+            |      'Field Name':field_name_list,
+            |      'Field Description':field_desc_list,
+            |      'Field Type': field_type_list
+            |  }
+
+
+        :meta private:
         """
         reformed_dict = {}
         source_list = []
@@ -567,16 +907,20 @@ class OmixAtlas:
     def nested_dict_to_df(self, schema_dict: dict) -> pd.DataFrame:
         """
         Convert flatten dict into df and print it
-        Input:
-              {
-                     'Source':source_list,
-                     'Datatype': datatype_list,
-                     'Field Name':field_name_list,
-                     'Field Description':field_desc_list,
-                     'Field Type': field_type_list
-              }
-        Output:
-              DataFrame
+
+        ``Args:``
+            |  {
+            |      'Source':source_list,
+            |      'Datatype': datatype_list,
+            |      'Field Name':field_name_list,
+            |      'Field Description':field_desc_list,
+            |      'Field Type': field_type_list
+            |  }
+
+        ``Returns:``
+            DataFrame
+
+        :meta private:
         """
         pd.options.display.max_columns = None
         pd.options.display.width = None
@@ -586,27 +930,57 @@ class OmixAtlas:
     def format_type(self, data: dict) -> dict:
         """
         Format the dict data
+
+        :meta private:
         """
         if data and isinstance(data, Dict):
             return json.dumps(data, indent=4)
 
     def insert_schema(self, repo_key: str, body: dict) -> dict:
         """
-        Params:
-            repo_key => str => <owner_name.repo_name> / <repo_id>
-            body => dict
-            {
-                "data": {
-                    "id": "<REPO_KEY>",
-                    "type": "schema",
-                    "attributes": {
-                    "schema_type": "files | gct_metadata | h5ad_metadata",
-                    "schema": {
-                        ... field definitions
+        Use insert_schema(repo_key, payload) to update the existing schema of an OmixAtlas.
+
+
+        .. code::
+
+
+                omixatlas.insert_schema(repo_key, payload)
+
+        ``Args :``
+            |  ``repo_key:`` (str) repo_id OR repo_name. This is a mandatory field.
+            |  ``payload:`` (dict) The payload is a JSON file which should be as per the structure defined for\
+ schema. Only data-admin will have the authentication to update the schema.
+
+            .. code::
+
+
+                    {
+                        "data": {
+                            "id": "<REPO_KEY>",
+                            "type": "schema",
+                            "attributes": {
+                            "schema_type": "files | gct_metadata | h5ad_metadata",
+                            "schema": {
+                                ... field definitions
+                            }
+                            }
+                        }
                     }
-                    }
-                }
-            }
+            |  ``payload`` can be loaded from the JSON file in which schema is defined in the following manner:
+
+            .. code::
+
+
+                    import json
+
+                    # Opening JSON file
+                    schema = open('schema_file.json')
+
+                    # returns JSON object as a dictionary
+                    payload = json.load(schema)
+
+        ``Errors:``
+            |  ``apiErrorException:`` Params are either empty or its datatype is not correct or see detail.
         """
         if repo_key and body and isinstance(body, dict):
             body = json.dumps(body)
@@ -626,21 +1000,44 @@ class OmixAtlas:
 
     def update_schema(self, repo_key: str, body: dict) -> dict:
         """
-        Params:
-                repo_key => str => <owner_name.repo_name> / <repo_id>
-                body => dict
-                {
-                    "data": {
-                        "id": "<REPO_KEY>",
-                        "type": "schema",
-                        "attributes": {
-                        "schema_type": "files | gct_metadata | h5ad_metadata",
-                        "schema": {
-                            ... field definitions
-                        }
+        Use update_schema(repo_key, payload) to update the existing schema of an OmixAtlas.
+
+        .. code::
+
+
+                omixatlas.update_schema(repo_key, payload)
+        ``Args :``
+            |  ``repo_key (str):`` repo_id OR repo_name. This is a mandatory field.
+            |  ``payload (dict):`` The payload is a JSON file which should be as per the structure defined for\
+ schema. Only data-admin will have the authentication to update the schema.
+
+            .. code::
+
+
+                    {
+                        "data": {
+                            "id": "<REPO_KEY>",
+                            "type": "schema",
+                            "attributes": {
+                            "schema_type": "files | gct_metadata | h5ad_metadata",
+                            "schema": {
+                                ... field definitions
+                            }
+                            }
                         }
                     }
-                }
+            |  ``payload`` can be loaded from the JSON file in which schema is defined in the following manner:
+
+            .. code::
+
+
+                    import json
+                    # Opening JSON file
+                    schema = open('schema_file.json')
+                    # returns JSON object as a dictionary
+                    payload = json.load(schema)
+        ``Errors:``
+            |  ``apiErrorException:`` Params are either empty or its datatype is not correct or see detail.
         """
         schema_type = body["data"]["attributes"]["schema_type"]
         schema_base_url = f"{self.discover_url}/repositories"
@@ -660,6 +1057,51 @@ class OmixAtlas:
             )
 
     def download_data(self, repo_name, _id: str):
+        """
+        Use update_schema(repo_key, payload) to update the existing schema of an OmixAtlas.
+
+        .. code::
+
+
+                omixatlas.update_schema(repo_key, payload)
+
+        ``Args :``
+            |  ``repo_key (str):`` repo_id OR repo_name. This is a mandatory field.
+            |  ``payload (dict):`` The payload is a JSON file which should be as per the structure defined for\
+ schema. Only data-admin will have the authentication to update the schema.
+
+            .. code::
+
+
+                    {
+                        "data": {
+                            "id": "<REPO_KEY>",
+                            "type": "schema",
+                            "attributes": {
+                            "schema_type": "files | gct_metadata | h5ad_metadata",
+                            "schema": {
+                                ... field definitions
+                            }
+                            }
+                        }
+                    }
+            |  ``payload`` can be loaded from the JSON file in which schema is defined in the following manner:
+
+
+            .. code::
+
+
+                    import json
+
+                    # Opening JSON file
+                    schema = open('schema_file.json')
+
+                    # returns JSON object as a dictionary
+                    payload = json.load(schema)
+
+        ``Errors:``
+            |  ``apiErrorException:`` Params are either empty or its datatype is not correct or see detail.
+        """
         url = f"{self.resource_url}/{repo_name}/download"
         params = {"_id": _id}
         response = self.session.get(url, params=params)
@@ -671,7 +1113,21 @@ class OmixAtlas:
     ) -> json:
         """
         Function for saving data from omixatlas to workspaces.
-        Makes a call to v1/omixatlas/workspace_jobs
+
+        ``Args:``
+            |  ``repo_id (str) :`` repo id.
+            |  ``dataset_id (str) :`` dataset id.
+            |  ``workspace_id (str) :`` workspace id of polly.
+            |  ``workspace_path (str) :`` path in workspace where you want to save file.
+
+        | Example to save the dataset_id ``'GSE101127_GPL1355'`` from repo_id ``1615965444377`` to a \
+workspace_id ``8025`` in a folder named ``'data'``.
+
+
+        .. code::
+
+
+                omixatlas.save_to_workspace('1615965444377', 'GSE101127_GPL1355', 8025, 'data')
         """
         url = f"{self.resource_url}/workspace_jobs"
         params = {"action": "copy"}
@@ -695,7 +1151,25 @@ class OmixAtlas:
 
     def format_converter(self, repo_key: str, dataset_id: str, to: str) -> None:
         """
-        Function to convert a file to maf format.
+        Function to convert a file format.
+
+        ``Args:``
+            |  ``repo_key (str) :`` repo_id.
+            |  ``dataset_id (str) :`` dataset_id.
+            |  ``to(str) :`` output file format.
+
+        |  For example:
+
+
+        .. code::
+
+
+                omixatlas.format_converter("cbioportal", "ACC_2019_Mutation_ACYC-FMI-19", "maf")
+
+        ``Errors:``
+            |  ``InvalidParameterException:`` invalid value of any parameter for example like - repo_id or \
+repo_name etc.
+            |  ``paramException:`` Incompatible or empty value of any parameter
         """
         if not (repo_key and isinstance(repo_key, str)):
             raise InvalidParameterException("repo_id/repo_name")
@@ -704,10 +1178,10 @@ class OmixAtlas:
         if not (to and isinstance(to, str)):
             raise InvalidParameterException("convert_to")
         ssl._create_default_https_context = ssl._create_unverified_context
-        response_omixatlas = self.omixatlas_summary(repo_key)
-        data = response_omixatlas.get("data")
+        response_omixatlas = self.get_omixatlas(repo_key)
+        data = response_omixatlas.get("data").get("attributes")
         repo_name = data.get("repo_name")
-        index_name = data.get("indexes", {}).get("files")
+        index_name = data.get("v2_indexes", {}).get("files")
         if index_name is None:
             raise paramException(
                 title="Param Error", detail="Repo entered is not an omixatlas."
@@ -762,18 +1236,36 @@ class OmixAtlas:
         components=[],
     ) -> pd.DataFrame:
         """
-        This function is used to create a new omixatlas
-        Args:
-            | display_name(str): display name of the omixatlas
-            | description(str): description of the omixatlas
-            | repo_name(str): repo_name which is used to create index in db
-            | image_url(str): Url of the icon for omixatlas. Optional Parameter
-            | initials(str): Initials shown in the icon of omixatlas. Optional Parameter
-            | explorer_enabled(bool): Default True. Optional Parameter
-            | studio_presets(list): Optional Paramter
-            | components(list): Optional Parameter
-        Returns:
-            | Dataframe after creation of omixatlas
+        This function is used to create a new omixatlas,
+
+        ``Args:``
+            | ``display_name (str):`` display name of the omixatlas.
+            | ``description (str):`` description of the omixatlas.
+            | ``repo_name (str):`` repo_name which is used to create index in db.
+            | ``image_url (str):`` Url of the icon for omixatlas. Optional Parameter.
+            | ``initials (str):`` Initials shown in the icon of omixatlas. Optional Parameter.
+            | ``explorer_enabled (bool):`` Default True. Optional Parameter.
+            | ``studio_presets (list):`` Optional Paramter.
+            | ``components (list):`` Optional Parameter.
+
+        ``Returns:``
+            | Dataframe after creation of omixatlas.
+
+        ``Errors:``
+            |  ``ValueError:`` Repository creation response is in Incorrect format.
+
+        | To use this function import Omixatlas class and make a object.
+
+
+        .. code::
+
+
+                from polly.omixatlas import OmixAtlas
+                omixatlas = OmixAtlas(token)
+                # to use OmixAtlas class functions
+                omixatlas.create(display_name, description, repo_name, image_url, initials, explorer_enabled,\
+studio_presets, components)
+
         """
         payload = self._get_repository_payload()
         frontend_info = {}
@@ -820,6 +1312,7 @@ class OmixAtlas:
     ) -> pd.DataFrame:
         """
         This function is used to update an omixatlas
+
         Args:
             | repo_name(str/int): repo_name/repo_id for that Omixatlas
             | display_name(str): display name of the omixatlas. Optional Parameter
